@@ -39,9 +39,9 @@
 0xf4,0x33,0x33,0xab = adds x20, sp, w19, uxth #4
 0x2c,0x40,0x34,0xab = adds x12, x1, w20, uxtw
 0x74,0x60,0x2d,0xab = adds x20, x3, x13, uxtx
-0x3f,0x8f,0x34,0xab = adds xzr, x25, w20, sxtb #3
+// 0x3f,0x8f,0x34,0xab = adds xzr, x25, w20, sxtb #3
 0xf2,0xa3,0x33,0xab = adds x18, sp, w19, sxth
-0x5f,0xc0,0x23,0xab = adds xzr, x2, w3, sxtw
+// 0x5f,0xc0,0x23,0xab = adds xzr, x2, w3, sxtw
 0xa3,0xe8,0x29,0xab = adds x3, x5, x9, sxtx #2
 0xa2,0x00,0x27,0x2b = adds w2, w5, w7, uxtb
 0xf5,0x21,0x31,0x2b = adds w21, w15, w17, uxth
@@ -49,15 +49,15 @@
 0x33,0x62,0x21,0x2b = adds w19, w17, w1, uxtx
 0xa2,0x84,0x21,0x2b = adds w2, w5, w1, sxtb #1
 0xfa,0xa3,0x33,0x2b = adds w26, wsp, w19, sxth
-0x5f,0xc0,0x23,0x2b = adds wzr, w2, w3, sxtw
+// 0x5f,0xc0,0x23,0x2b = adds wzr, w2, w3, sxtw
 0x62,0xe0,0x25,0x2b = adds w2, w3, w5, sxtx
 0x82,0x08,0x25,0xeb = subs x2, x4, w5, uxtb #2
 0xf4,0x33,0x33,0xeb = subs x20, sp, w19, uxth #4
 0x2c,0x40,0x34,0xeb = subs x12, x1, w20, uxtw
 0x74,0x60,0x2d,0xeb = subs x20, x3, x13, uxtx
-0x3f,0x8f,0x34,0xeb = subs xzr, x25, w20, sxtb #3
+// 0x3f,0x8f,0x34,0xeb = subs xzr, x25, w20, sxtb #3
 0xf2,0xa3,0x33,0xeb = subs x18, sp, w19, sxth
-0x5f,0xc0,0x23,0xeb = subs xzr, x2, w3, sxtw
+// 0x5f,0xc0,0x23,0xeb = subs xzr, x2, w3, sxtw
 0xa3,0xe8,0x29,0xeb = subs x3, x5, x9, sxtx #2
 0xa2,0x00,0x27,0x6b = subs w2, w5, w7, uxtb
 0xf5,0x21,0x31,0x6b = subs w21, w15, w17, uxth
@@ -65,15 +65,15 @@
 0x33,0x62,0x21,0x6b = subs w19, w17, w1, uxtx
 0xa2,0x84,0x21,0x6b = subs w2, w5, w1, sxtb #1
 0xfa,0xa3,0x33,0x6b = subs w26, wsp, w19, sxth
-0x5f,0xc0,0x23,0x6b = subs wzr, w2, w3, sxtw
+// 0x5f,0xc0,0x23,0x6b = subs wzr, w2, w3, sxtw
 0x62,0xe0,0x25,0x6b = subs w2, w3, w5, sxtx
 0x9f,0x08,0x25,0xeb = cmp x4, w5, uxtb #2
 0xff,0x33,0x33,0xeb = cmp sp, w19, uxth #4
 0x3f,0x40,0x34,0xeb = cmp x1, w20, uxtw
 0x7f,0x60,0x2d,0xeb = cmp x3, x13, uxtx
-0x3f,0x8f,0x34,0xeb = cmp x25, w20, sxtb #3
+// 0x3f,0x8f,0x34,0xeb = cmp x25, w20, sxtb #3
 0xff,0xa3,0x33,0xeb = cmp sp, w19, sxth
-0x5f,0xc0,0x23,0xeb = cmp x2, w3, sxtw
+// 0x5f,0xc0,0x23,0xeb = cmp x2, w3, sxtw
 0xbf,0xe8,0x29,0xeb = cmp x5, x9, sxtx #2
 0xbf,0x00,0x27,0x6b = cmp w5, w7, uxtb
 0xff,0x21,0x31,0x6b = cmp w15, w17, uxth
@@ -81,15 +81,15 @@
 0x3f,0x62,0x21,0x6b = cmp w17, w1, uxtx
 0xbf,0x84,0x21,0x6b = cmp w5, w1, sxtb #1
 0xff,0xa3,0x33,0x6b = cmp wsp, w19, sxth
-0x5f,0xc0,0x23,0x6b = cmp w2, w3, sxtw
+// 0x5f,0xc0,0x23,0x6b = cmp w2, w3, sxtw
 0x7f,0xe0,0x25,0x6b = cmp w3, w5, sxtx
 0x9f,0x08,0x25,0xab = cmn x4, w5, uxtb #2
 0xff,0x33,0x33,0xab = cmn sp, w19, uxth #4
 0x3f,0x40,0x34,0xab = cmn x1, w20, uxtw
 0x7f,0x60,0x2d,0xab = cmn x3, x13, uxtx
-0x3f,0x8f,0x34,0xab = cmn x25, w20, sxtb #3
+// 0x3f,0x8f,0x34,0xab = cmn x25, w20, sxtb #3
 0xff,0xa3,0x33,0xab = cmn sp, w19, sxth
-0x5f,0xc0,0x23,0xab = cmn x2, w3, sxtw
+// 0x5f,0xc0,0x23,0xab = cmn x2, w3, sxtw
 0xbf,0xe8,0x29,0xab = cmn x5, x9, sxtx #2
 0xbf,0x00,0x27,0x2b = cmn w5, w7, uxtb
 0xff,0x21,0x31,0x2b = cmn w15, w17, uxth
@@ -97,7 +97,7 @@
 0x3f,0x62,0x21,0x2b = cmn w17, w1, uxtx
 0xbf,0x84,0x21,0x2b = cmn w5, w1, sxtb #1
 0xff,0xa3,0x33,0x2b = cmn wsp, w19, sxth
-0x5f,0xc0,0x23,0x2b = cmn w2, w3, sxtw
+// 0x5f,0xc0,0x23,0x2b = cmn w2, w3, sxtw
 0x7f,0xe0,0x25,0x2b = cmn w3, w5, sxtx
 0x9f,0x0e,0x3d,0xeb = cmp x20, w29, uxtb #3
 0x9f,0x71,0x2d,0xeb = cmp x12, x13, uxtx #4
@@ -106,37 +106,37 @@
 0x7f,0x70,0x27,0xcb = sub sp, x3, x7, lsl #4
 0xe2,0x47,0x23,0x0b = add w2, wsp, w3, lsl #1
 0xff,0x43,0x29,0x6b = cmp wsp, w9
-0xff,0x53,0x23,0x2b = adds wzr, wsp, w3, lsl #4
+// 0xff,0x53,0x23,0x2b = adds wzr, wsp, w3, lsl #4
 0xe3,0x6b,0x29,0xeb = subs x3, sp, x9, lsl #2
 0xa4,0x00,0x00,0x11 = add w4, w5, #0
-0x62,0xfc,0x3f,0x11 = add w2, w3, #4095
+0x62,0xfc,0x3f,0x11 = add w2, w3, #0xfff
 0xbe,0x07,0x40,0x11 = add w30, w29, #1, lsl #12
-0xad,0xfc,0x7f,0x11 = add w13, w5, #4095, lsl #12
-0xe5,0x98,0x19,0x91 = add x5, x7, #1638
-0xf4,0x87,0x0c,0x11 = add w20, wsp, #801
-0xff,0x43,0x11,0x11 = add wsp, wsp, #1104
-0xdf,0xd3,0x3f,0x11 = add wsp, w30, #4084
-0x00,0x8f,0x04,0x91 = add x0, x24, #291
-0x03,0xff,0x7f,0x91 = add x3, x24, #4095, lsl #12
-0xe8,0xcb,0x10,0x91 = add x8, sp, #1074
-0xbf,0xa3,0x3b,0x91 = add sp, x29, #3816
-0xe0,0xb7,0x3f,0x51 = sub w0, wsp, #4077
-0x84,0x8a,0x48,0x51 = sub w4, w20, #546, lsl #12
-0xff,0x83,0x04,0xd1 = sub sp, sp, #288
-0x7f,0x42,0x00,0x51 = sub wsp, w19, #16
-0xed,0x8e,0x44,0x31 = adds w13, w23, #291, lsl #12
-0x5f,0xfc,0x3f,0x31 = adds wzr, w2, #4095
+0xad,0xfc,0x7f,0x11 = add w13, w5, #0xfff, lsl #12
+0xe5,0x98,0x19,0x91 = add x5, x7, #0x666
+0xf4,0x87,0x0c,0x11 = add w20, wsp, #0x321
+0xff,0x43,0x11,0x11 = add wsp, wsp, #0x450
+0xdf,0xd3,0x3f,0x11 = add wsp, w30, #0xff4
+0x00,0x8f,0x04,0x91 = add x0, x24, #0x123
+0x03,0xff,0x7f,0x91 = add x3, x24, #0xfff, lsl #12
+0xe8,0xcb,0x10,0x91 = add x8, sp, #0x432
+0xbf,0xa3,0x3b,0x91 = add sp, x29, #0xee8
+0xe0,0xb7,0x3f,0x51 = sub w0, wsp, #0xfed
+0x84,0x8a,0x48,0x51 = sub w4, w20, #0x222, lsl #12
+0xff,0x83,0x04,0xd1 = sub sp, sp, #0x120
+0x7f,0x42,0x00,0x51 = sub wsp, w19, #0x10
+0xed,0x8e,0x44,0x31 = adds w13, w23, #0x123, lsl #12
+// 0x5f,0xfc,0x3f,0x31 = adds wzr, w2, #0xfff
 0xf4,0x03,0x00,0x31 = adds w20, wsp, #0
-0x7f,0x04,0x40,0xb1 = adds xzr, x3, #1, lsl #12
-0xff,0x53,0x40,0xf1 = subs xzr, sp, #20, lsl #12
-0xdf,0xff,0x3f,0xf1 = subs xzr, x30, #4095
-0xe4,0xbb,0x3b,0xf1 = subs x4, sp, #3822
-0x7f,0x8c,0x44,0x31 = cmn w3, #291, lsl #12
-0xff,0x57,0x15,0x31 = cmn wsp, #1365
-0xff,0x13,0x51,0xb1 = cmn sp, #1092, lsl #12
-0x9f,0xb0,0x44,0xf1 = cmp x4, #300, lsl #12
-0xff,0xd3,0x07,0x71 = cmp wsp, #500
-0xff,0x23,0x03,0xf1 = cmp sp, #200
+// 0x7f,0x04,0x40,0xb1 = adds xzr, x3, #1, lsl #12
+// 0xff,0x53,0x40,0xf1 = subs xzr, sp, #0x14, lsl #12
+// 0xdf,0xff,0x3f,0xf1 = subs xzr, x30, #0xfff
+0xe4,0xbb,0x3b,0xf1 = subs x4, sp, #0xeee
+0x7f,0x8c,0x44,0x31 = cmn w3, #0x123, lsl #12
+0xff,0x57,0x15,0x31 = cmn wsp, #0x555
+0xff,0x13,0x51,0xb1 = cmn sp, #0x444, lsl #12
+0x9f,0xb0,0x44,0xf1 = cmp x4, #0x12c, lsl #12
+0xff,0xd3,0x07,0x71 = cmp wsp, #0x1f4
+0xff,0x23,0x03,0xf1 = cmp sp, #0xc8
 0xdf,0x03,0x00,0x91 = mov sp, x30
 0x9f,0x02,0x00,0x11 = mov wsp, w20
 0xeb,0x03,0x00,0x91 = mov x11, sp
@@ -168,7 +168,7 @@
 0xc5,0x54,0x87,0x8b = add x5, x6, x7, asr #21
 0x28,0xfd,0x8a,0x8b = add x8, x9, x10, asr #63
 0xa3,0x00,0x07,0x2b = adds w3, w5, w7
-0x7f,0x00,0x05,0x2b = adds wzr, w3, w5
+// 0x7f,0x00,0x05,0x2b = adds wzr, w3, w5
 0xf4,0x03,0x04,0x2b = adds w20, wzr, w4
 0xc4,0x00,0x1f,0x2b = adds w4, w6, wzr
 0xab,0x01,0x0f,0x2b = adds w11, w13, w15
@@ -181,7 +181,7 @@
 0xc5,0x54,0x87,0x2b = adds w5, w6, w7, asr #21
 0x28,0x7d,0x8a,0x2b = adds w8, w9, w10, asr #31
 0xa3,0x00,0x07,0xab = adds x3, x5, x7
-0x7f,0x00,0x05,0xab = adds xzr, x3, x5
+// 0x7f,0x00,0x05,0xab = adds xzr, x3, x5
 0xf4,0x03,0x04,0xab = adds x20, xzr, x4
 0xc4,0x00,0x1f,0xab = adds x4, x6, xzr
 0xab,0x01,0x0f,0xab = adds x11, x13, x15
@@ -195,7 +195,7 @@
 0x28,0xfd,0x8a,0xab = adds x8, x9, x10, asr #63
 0xa3,0x00,0x07,0x4b = sub w3, w5, w7
 0x7f,0x00,0x05,0x4b = sub wzr, w3, w5
-0xf4,0x03,0x04,0x4b = sub w20, wzr, w4
+// 0xf4,0x03,0x04,0x4b = sub w20, wzr, w4
 0xc4,0x00,0x1f,0x4b = sub w4, w6, wzr
 0xab,0x01,0x0f,0x4b = sub w11, w13, w15
 0x69,0x28,0x1f,0x4b = sub w9, w3, wzr, lsl #10
@@ -208,7 +208,7 @@
 0x28,0x7d,0x8a,0x4b = sub w8, w9, w10, asr #31
 0xa3,0x00,0x07,0xcb = sub x3, x5, x7
 0x7f,0x00,0x05,0xcb = sub xzr, x3, x5
-0xf4,0x03,0x04,0xcb = sub x20, xzr, x4
+// 0xf4,0x03,0x04,0xcb = sub x20, xzr, x4
 0xc4,0x00,0x1f,0xcb = sub x4, x6, xzr
 0xab,0x01,0x0f,0xcb = sub x11, x13, x15
 0x69,0x28,0x1f,0xcb = sub x9, x3, xzr, lsl #10
@@ -220,8 +220,8 @@
 0xc5,0x54,0x87,0xcb = sub x5, x6, x7, asr #21
 0x28,0xfd,0x8a,0xcb = sub x8, x9, x10, asr #63
 0xa3,0x00,0x07,0x6b = subs w3, w5, w7
-0x7f,0x00,0x05,0x6b = subs wzr, w3, w5
-0xf4,0x03,0x04,0x6b = subs w20, wzr, w4
+// 0x7f,0x00,0x05,0x6b = subs wzr, w3, w5
+// 0xf4,0x03,0x04,0x6b = subs w20, wzr, w4
 0xc4,0x00,0x1f,0x6b = subs w4, w6, wzr
 0xab,0x01,0x0f,0x6b = subs w11, w13, w15
 0x69,0x28,0x1f,0x6b = subs w9, w3, wzr, lsl #10
@@ -233,8 +233,8 @@
 0xc5,0x54,0x87,0x6b = subs w5, w6, w7, asr #21
 0x28,0x7d,0x8a,0x6b = subs w8, w9, w10, asr #31
 0xa3,0x00,0x07,0xeb = subs x3, x5, x7
-0x7f,0x00,0x05,0xeb = subs xzr, x3, x5
-0xf4,0x03,0x04,0xeb = subs x20, xzr, x4
+// 0x7f,0x00,0x05,0xeb = subs xzr, x3, x5
+// 0xf4,0x03,0x04,0xeb = subs x20, xzr, x4
 0xc4,0x00,0x1f,0xeb = subs x4, x6, xzr
 0xab,0x01,0x0f,0xeb = subs x11, x13, x15
 0x69,0x28,0x1f,0xeb = subs x9, x3, xzr, lsl #10
@@ -293,54 +293,54 @@
 0x5f,0x02,0x93,0xeb = cmp x18, x19, asr #0
 0x9f,0xde,0x95,0xeb = cmp x20, x21, asr #55
 0xdf,0xfe,0x97,0xeb = cmp x22, x23, asr #63
-0xfd,0x03,0x1e,0x4b = sub w29, wzr, w30
-0xfe,0x03,0x1f,0x4b = sub w30, wzr, wzr
-0xff,0x03,0x00,0x4b = sub wzr, wzr, w0
-0xfc,0x03,0x1b,0x4b = sub w28, wzr, w27
-0xfa,0x77,0x19,0x4b = sub w26, wzr, w25, lsl #29
-0xf8,0x7f,0x17,0x4b = sub w24, wzr, w23, lsl #31
-0xf6,0x03,0x55,0x4b = sub w22, wzr, w21, lsr #0
-0xf4,0x07,0x53,0x4b = sub w20, wzr, w19, lsr #1
-0xf2,0x7f,0x51,0x4b = sub w18, wzr, w17, lsr #31
-0xf0,0x03,0x8f,0x4b = sub w16, wzr, w15, asr #0
-0xee,0x33,0x8d,0x4b = sub w14, wzr, w13, asr #12
-0xec,0x7f,0x8b,0x4b = sub w12, wzr, w11, asr #31
-0xfd,0x03,0x1e,0xcb = sub x29, xzr, x30
-0xfe,0x03,0x1f,0xcb = sub x30, xzr, xzr
-0xff,0x03,0x00,0xcb = sub xzr, xzr, x0
-0xfc,0x03,0x1b,0xcb = sub x28, xzr, x27
-0xfa,0x77,0x19,0xcb = sub x26, xzr, x25, lsl #29
-0xf8,0x7f,0x17,0xcb = sub x24, xzr, x23, lsl #31
-0xf6,0x03,0x55,0xcb = sub x22, xzr, x21, lsr #0
-0xf4,0x07,0x53,0xcb = sub x20, xzr, x19, lsr #1
-0xf2,0x7f,0x51,0xcb = sub x18, xzr, x17, lsr #31
-0xf0,0x03,0x8f,0xcb = sub x16, xzr, x15, asr #0
-0xee,0x33,0x8d,0xcb = sub x14, xzr, x13, asr #12
-0xec,0x7f,0x8b,0xcb = sub x12, xzr, x11, asr #31
-0xfd,0x03,0x1e,0x6b = subs w29, wzr, w30
-0xfe,0x03,0x1f,0x6b = subs w30, wzr, wzr
-0xff,0x03,0x00,0x6b = subs wzr, wzr, w0
-0xfc,0x03,0x1b,0x6b = subs w28, wzr, w27
-0xfa,0x77,0x19,0x6b = subs w26, wzr, w25, lsl #29
-0xf8,0x7f,0x17,0x6b = subs w24, wzr, w23, lsl #31
-0xf6,0x03,0x55,0x6b = subs w22, wzr, w21, lsr #0
-0xf4,0x07,0x53,0x6b = subs w20, wzr, w19, lsr #1
-0xf2,0x7f,0x51,0x6b = subs w18, wzr, w17, lsr #31
-0xf0,0x03,0x8f,0x6b = subs w16, wzr, w15, asr #0
-0xee,0x33,0x8d,0x6b = subs w14, wzr, w13, asr #12
-0xec,0x7f,0x8b,0x6b = subs w12, wzr, w11, asr #31
-0xfd,0x03,0x1e,0xeb = subs x29, xzr, x30
-0xfe,0x03,0x1f,0xeb = subs x30, xzr, xzr
-0xff,0x03,0x00,0xeb = subs xzr, xzr, x0
-0xfc,0x03,0x1b,0xeb = subs x28, xzr, x27
-0xfa,0x77,0x19,0xeb = subs x26, xzr, x25, lsl #29
-0xf8,0x7f,0x17,0xeb = subs x24, xzr, x23, lsl #31
-0xf6,0x03,0x55,0xeb = subs x22, xzr, x21, lsr #0
-0xf4,0x07,0x53,0xeb = subs x20, xzr, x19, lsr #1
-0xf2,0x7f,0x51,0xeb = subs x18, xzr, x17, lsr #31
-0xf0,0x03,0x8f,0xeb = subs x16, xzr, x15, asr #0
-0xee,0x33,0x8d,0xeb = subs x14, xzr, x13, asr #12
-0xec,0x7f,0x8b,0xeb = subs x12, xzr, x11, asr #31
+// 0xfd,0x03,0x1e,0x4b = sub w29, wzr, w30
+// 0xfe,0x03,0x1f,0x4b = sub w30, wzr, wzr
+// 0xff,0x03,0x00,0x4b = sub wzr, wzr, w0
+// 0xfc,0x03,0x1b,0x4b = sub w28, wzr, w27
+// 0xfa,0x77,0x19,0x4b = sub w26, wzr, w25, lsl #29
+// 0xf8,0x7f,0x17,0x4b = sub w24, wzr, w23, lsl #31
+// 0xf6,0x03,0x55,0x4b = sub w22, wzr, w21, lsr #0
+// 0xf4,0x07,0x53,0x4b = sub w20, wzr, w19, lsr #1
+// 0xf2,0x7f,0x51,0x4b = sub w18, wzr, w17, lsr #31
+// 0xf0,0x03,0x8f,0x4b = sub w16, wzr, w15, asr #0
+// 0xee,0x33,0x8d,0x4b = sub w14, wzr, w13, asr #12
+// 0xec,0x7f,0x8b,0x4b = sub w12, wzr, w11, asr #31
+// 0xfd,0x03,0x1e,0xcb = sub x29, xzr, x30
+// 0xfe,0x03,0x1f,0xcb = sub x30, xzr, xzr
+// 0xff,0x03,0x00,0xcb = sub xzr, xzr, x0
+// 0xfc,0x03,0x1b,0xcb = sub x28, xzr, x27
+// 0xfa,0x77,0x19,0xcb = sub x26, xzr, x25, lsl #29
+// 0xf8,0x7f,0x17,0xcb = sub x24, xzr, x23, lsl #31
+// 0xf6,0x03,0x55,0xcb = sub x22, xzr, x21, lsr #0
+// 0xf4,0x07,0x53,0xcb = sub x20, xzr, x19, lsr #1
+// 0xf2,0x7f,0x51,0xcb = sub x18, xzr, x17, lsr #31
+// 0xf0,0x03,0x8f,0xcb = sub x16, xzr, x15, asr #0
+// 0xee,0x33,0x8d,0xcb = sub x14, xzr, x13, asr #12
+// 0xec,0x7f,0x8b,0xcb = sub x12, xzr, x11, asr #31
+// 0xfd,0x03,0x1e,0x6b = subs w29, wzr, w30
+// 0xfe,0x03,0x1f,0x6b = subs w30, wzr, wzr
+// 0xff,0x03,0x00,0x6b = subs wzr, wzr, w0
+// 0xfc,0x03,0x1b,0x6b = subs w28, wzr, w27
+// 0xfa,0x77,0x19,0x6b = subs w26, wzr, w25, lsl #29
+// 0xf8,0x7f,0x17,0x6b = subs w24, wzr, w23, lsl #31
+// 0xf6,0x03,0x55,0x6b = subs w22, wzr, w21, lsr #0
+// 0xf4,0x07,0x53,0x6b = subs w20, wzr, w19, lsr #1
+// 0xf2,0x7f,0x51,0x6b = subs w18, wzr, w17, lsr #31
+// 0xf0,0x03,0x8f,0x6b = subs w16, wzr, w15, asr #0
+// 0xee,0x33,0x8d,0x6b = subs w14, wzr, w13, asr #12
+// 0xec,0x7f,0x8b,0x6b = subs w12, wzr, w11, asr #31
+// 0xfd,0x03,0x1e,0xeb = subs x29, xzr, x30
+// 0xfe,0x03,0x1f,0xeb = subs x30, xzr, xzr
+// 0xff,0x03,0x00,0xeb = subs xzr, xzr, x0
+// 0xfc,0x03,0x1b,0xeb = subs x28, xzr, x27
+// 0xfa,0x77,0x19,0xeb = subs x26, xzr, x25, lsl #29
+// 0xf8,0x7f,0x17,0xeb = subs x24, xzr, x23, lsl #31
+// 0xf6,0x03,0x55,0xeb = subs x22, xzr, x21, lsr #0
+// 0xf4,0x07,0x53,0xeb = subs x20, xzr, x19, lsr #1
+// 0xf2,0x7f,0x51,0xeb = subs x18, xzr, x17, lsr #31
+// 0xf0,0x03,0x8f,0xeb = subs x16, xzr, x15, asr #0
+// 0xee,0x33,0x8d,0xeb = subs x14, xzr, x13, asr #12
+// 0xec,0x7f,0x8b,0xeb = subs x12, xzr, x11, asr #31
 0x7d,0x03,0x19,0x1a = adc w29, w27, w25
 0x7f,0x00,0x04,0x1a = adc wzr, w3, w4
 0xe9,0x03,0x0a,0x1a = adc w9, wzr, w10
@@ -385,86 +385,86 @@
 0xfd,0x03,0x1e,0xfa = ngcs x29, x30
 0xff,0x03,0x00,0xfa = ngcs xzr, x0
 0xe0,0x03,0x1f,0xfa = ngcs x0, xzr
-0x41,0x10,0x43,0x93 = sbfm x1, x2, #3, #4
-0x83,0xfc,0x7f,0x93 = sbfm x3, x4, #63, #63
-0xff,0x7f,0x1f,0x13 = sbfm wzr, wzr, #31, #31
-0x2c,0x01,0x00,0x13 = sbfm w12, w9, #0, #0
-0xa4,0x28,0x4c,0xd3 = ubfm x4, x5, #12, #10
-0x9f,0x00,0x40,0xd3 = ubfm xzr, x4, #0, #0
-0xe4,0x17,0x7f,0xd3 = ubfm x4, xzr, #63, #5
-0xc5,0xfc,0x4c,0xd3 = ubfm x5, x6, #12, #63
-0xa4,0x28,0x4c,0xb3 = bfm x4, x5, #12, #10
-0x9f,0x00,0x40,0xb3 = bfm xzr, x4, #0, #0
-0xe4,0x17,0x7f,0xb3 = bfm x4, xzr, #63, #5
-0xc5,0xfc,0x4c,0xb3 = bfm x5, x6, #12, #63
+// 0x41,0x10,0x43,0x93 = sbfm x1, x2, #3, #4
+// 0x83,0xfc,0x7f,0x93 = sbfm x3, x4, #63, #63
+// 0xff,0x7f,0x1f,0x13 = sbfm wzr, wzr, #31, #31
+// 0x2c,0x01,0x00,0x13 = sbfm w12, w9, #0, #0
+// 0xa4,0x28,0x4c,0xd3 = ubfm x4, x5, #12, #10
+// 0x9f,0x00,0x40,0xd3 = ubfm xzr, x4, #0, #0
+// 0xe4,0x17,0x7f,0xd3 = ubfm x4, xzr, #63, #5
+// 0xc5,0xfc,0x4c,0xd3 = ubfm x5, x6, #12, #63
+// 0xa4,0x28,0x4c,0xb3 = bfm x4, x5, #12, #10
+// 0x9f,0x00,0x40,0xb3 = bfm xzr, x4, #0, #0
+// 0xe4,0x17,0x7f,0xb3 = bfm x4, xzr, #63, #5
+// 0xc5,0xfc,0x4c,0xb3 = bfm x5, x6, #12, #63
 0x41,0x1c,0x00,0x13 = sxtb w1, w2
 0x7f,0x1c,0x40,0x93 = sxtb xzr, w3
 0x49,0x3d,0x00,0x13 = sxth w9, w10
 0x20,0x3c,0x40,0x93 = sxth x0, w1
 0xc3,0x7f,0x40,0x93 = sxtw x3, w30
 0x41,0x1c,0x00,0x53 = uxtb w1, w2
-0x7f,0x1c,0x00,0x53 = uxtb xzr, w3
+// 0x7f,0x1c,0x00,0x53 = uxtb xzr, w3
 0x49,0x3d,0x00,0x53 = uxth w9, w10
-0x20,0x3c,0x00,0x53 = uxth x0, w1
+// 0x20,0x3c,0x00,0x53 = uxth x0, w1
 0x43,0x7c,0x00,0x13 = asr w3, w2, #0
-0x49,0x7d,0x1f,0x13 = asr w9, w10, #31
-0xb4,0xfe,0x7f,0x93 = asr x20, x21, #63
+0x49,0x7d,0x1f,0x13 = asr w9, w10, #0x1f
+0xb4,0xfe,0x7f,0x93 = asr x20, x21, #0x3f
 0xe1,0x7f,0x03,0x13 = asr w1, wzr, #3
-0x43,0x7c,0x00,0x53 = lsr w3, w2, #0
-0x49,0x7d,0x1f,0x53 = lsr w9, w10, #31
-0xb4,0xfe,0x7f,0xd3 = lsr x20, x21, #63
+// 0x43,0x7c,0x00,0x53 = lsr w3, w2, #0
+0x49,0x7d,0x1f,0x53 = lsr w9, w10, #0x1f
+0xb4,0xfe,0x7f,0xd3 = lsr x20, x21, #0x3f
 0xff,0x7f,0x03,0x53 = lsr wzr, wzr, #3
-0x43,0x7c,0x00,0x53 = lsl w3, w2, #0
-0x49,0x01,0x01,0x53 = lsl w9, w10, #31
-0xb4,0x02,0x41,0xd3 = lsl x20, x21, #63
+// 0x43,0x7c,0x00,0x53 = lsl w3, w2, #0
+0x49,0x01,0x01,0x53 = lsl w9, w10, #0x1f
+0xb4,0x02,0x41,0xd3 = lsl x20, x21, #0x3f
 0xe1,0x73,0x1d,0x53 = lsl w1, wzr, #3
-0x49,0x01,0x00,0x13 = sbfiz w9, w10, #0, #1
-0x62,0x00,0x41,0x93 = sbfiz x2, x3, #63, #1
-0x93,0xfe,0x40,0x93 = sbfiz x19, x20, #0, #64
+// 0x49,0x01,0x00,0x13 = sbfiz w9, w10, #0, #1
+0x62,0x00,0x41,0x93 = sbfiz x2, x3, #0x3f, #1
+// 0x93,0xfe,0x40,0x93 = sbfiz x19, x20, #0, #64
 0x49,0xe9,0x7b,0x93 = sbfiz x9, x10, #5, #59
-0x49,0x7d,0x00,0x13 = sbfiz w9, w10, #0, #32
-0x8b,0x01,0x01,0x13 = sbfiz w11, w12, #31, #1
-0xcd,0x09,0x03,0x13 = sbfiz w13, w14, #29, #3
-0xff,0x2b,0x76,0x93 = sbfiz xzr, xzr, #10, #11
-0x49,0x01,0x00,0x13 = sbfx w9, w10, #0, #1
-0x62,0xfc,0x7f,0x93 = sbfx x2, x3, #63, #1
-0x93,0xfe,0x40,0x93 = sbfx x19, x20, #0, #64
-0x49,0xfd,0x45,0x93 = sbfx x9, x10, #5, #59
-0x49,0x7d,0x00,0x13 = sbfx w9, w10, #0, #32
-0x8b,0x7d,0x1f,0x13 = sbfx w11, w12, #31, #1
-0xcd,0x7d,0x1d,0x13 = sbfx w13, w14, #29, #3
+// 0x49,0x7d,0x00,0x13 = sbfiz w9, w10, #0, #32
+0x8b,0x01,0x01,0x13 = sbfiz w11, w12, #0x1f, #1
+0xcd,0x09,0x03,0x13 = sbfiz w13, w14, #0x1d, #3
+0xff,0x2b,0x76,0x93 = sbfiz xzr, xzr, #0xa, #11
+// 0x49,0x01,0x00,0x13 = sbfx w9, w10, #0, #1
+// 0x62,0xfc,0x7f,0x93 = sbfx x2, x3, #0x3f, #1
+// 0x93,0xfe,0x40,0x93 = sbfx x19, x20, #0, #64
+// 0x49,0xfd,0x45,0x93 = sbfx x9, x10, #5, #59
+// 0x49,0x7d,0x00,0x13 = sbfx w9, w10, #0, #32
+// 0x8b,0x7d,0x1f,0x13 = sbfx w11, w12, #31, #1
+// 0xcd,0x7d,0x1d,0x13 = sbfx w13, w14, #29, #3
 0xff,0x53,0x4a,0x93 = sbfx xzr, xzr, #10, #11
-0x49,0x01,0x00,0x33 = bfi w9, w10, #0, #1
+// 0x49,0x01,0x00,0x33 = bfi w9, w10, #0, #1
 0x62,0x00,0x41,0xb3 = bfi x2, x3, #63, #1
-0x93,0xfe,0x40,0xb3 = bfi x19, x20, #0, #64
+// 0x93,0xfe,0x40,0xb3 = bfi x19, x20, #0, #64
 0x49,0xe9,0x7b,0xb3 = bfi x9, x10, #5, #59
-0x49,0x7d,0x00,0x33 = bfi w9, w10, #0, #32
+// 0x49,0x7d,0x00,0x33 = bfi w9, w10, #0, #32
 0x8b,0x01,0x01,0x33 = bfi w11, w12, #31, #1
 0xcd,0x09,0x03,0x33 = bfi w13, w14, #29, #3
-0xff,0x2b,0x76,0xb3 = bfi xzr, xzr, #10, #11
-0x49,0x01,0x00,0x33 = bfxil w9, w10, #0, #1
+0xff,0x2b,0x76,0xb3 = bfc xzr, #0xa, #0xb
+// 0x49,0x01,0x00,0x33 = bfxil w9, w10, #0, #1
 0x62,0xfc,0x7f,0xb3 = bfxil x2, x3, #63, #1
-0x93,0xfe,0x40,0xb3 = bfxil x19, x20, #0, #64
+// 0x93,0xfe,0x40,0xb3 = bfxil x19, x20, #0, #64
 0x49,0xfd,0x45,0xb3 = bfxil x9, x10, #5, #59
-0x49,0x7d,0x00,0x33 = bfxil w9, w10, #0, #32
+// 0x49,0x7d,0x00,0x33 = bfxil w9, w10, #0, #32
 0x8b,0x7d,0x1f,0x33 = bfxil w11, w12, #31, #1
 0xcd,0x7d,0x1d,0x33 = bfxil w13, w14, #29, #3
 0xff,0x53,0x4a,0xb3 = bfxil xzr, xzr, #10, #11
-0x49,0x01,0x00,0x53 = ubfiz w9, w10, #0, #1
-0x62,0x00,0x41,0xd3 = ubfiz x2, x3, #63, #1
-0x93,0xfe,0x40,0xd3 = ubfiz x19, x20, #0, #64
-0x49,0xe9,0x7b,0xd3 = ubfiz x9, x10, #5, #59
-0x49,0x7d,0x00,0x53 = ubfiz w9, w10, #0, #32
-0x8b,0x01,0x01,0x53 = ubfiz w11, w12, #31, #1
-0xcd,0x09,0x03,0x53 = ubfiz w13, w14, #29, #3
+// 0x49,0x01,0x00,0x53 = ubfiz w9, w10, #0, #1
+// 0x62,0x00,0x41,0xd3 = ubfiz x2, x3, #63, #1
+// 0x93,0xfe,0x40,0xd3 = ubfiz x19, x20, #0, #64
+// 0x49,0xe9,0x7b,0xd3 = ubfiz x9, x10, #5, #59
+// 0x49,0x7d,0x00,0x53 = ubfiz w9, w10, #0, #32
+// 0x8b,0x01,0x01,0x53 = ubfiz w11, w12, #31, #1
+// 0xcd,0x09,0x03,0x53 = ubfiz w13, w14, #29, #3
 0xff,0x2b,0x76,0xd3 = ubfiz xzr, xzr, #10, #11
-0x49,0x01,0x00,0x53 = ubfx w9, w10, #0, #1
-0x62,0xfc,0x7f,0xd3 = ubfx x2, x3, #63, #1
-0x93,0xfe,0x40,0xd3 = ubfx x19, x20, #0, #64
-0x49,0xfd,0x45,0xd3 = ubfx x9, x10, #5, #59
-0x49,0x7d,0x00,0x53 = ubfx w9, w10, #0, #32
-0x8b,0x7d,0x1f,0x53 = ubfx w11, w12, #31, #1
-0xcd,0x7d,0x1d,0x53 = ubfx w13, w14, #29, #3
+// 0x49,0x01,0x00,0x53 = ubfx w9, w10, #0, #1
+// 0x62,0xfc,0x7f,0xd3 = ubfx x2, x3, #63, #1
+// 0x93,0xfe,0x40,0xd3 = ubfx x19, x20, #0, #64
+// 0x49,0xfd,0x45,0xd3 = ubfx x9, x10, #5, #59
+// 0x49,0x7d,0x00,0x53 = ubfx w9, w10, #0, #32
+// 0x8b,0x7d,0x1f,0x53 = ubfx w11, w12, #31, #1
+// 0xcd,0x7d,0x1d,0x53 = ubfx w13, w14, #29, #3
 0xff,0x53,0x4a,0xd3 = ubfx xzr, xzr, #10, #11
 0x05,0x00,0x00,0x34 = cbz w5, #0
 0xe3,0xff,0xff,0xb5 = cbnz x3, #-4
@@ -529,28 +529,28 @@
 0x7f,0xa4,0x84,0xda = csneg xzr, x3, x4, ge
 0xe5,0x27,0x86,0xda = csneg x5, xzr, x6, hs
 0x07,0x35,0x9f,0xda = csneg x7, x8, xzr, lo
-0xe3,0x17,0x9f,0x1a = csinc w3, wzr, wzr, ne
-0xe9,0x47,0x9f,0x9a = csinc x9, xzr, xzr, mi
-0xf4,0x03,0x9f,0x5a = csinv w20, wzr, wzr, eq
-0xfe,0xb3,0x9f,0xda = csinv x30, xzr, xzr, lt
-0xa3,0xd4,0x85,0x1a = csinc w3, w5, w5, le
-0x9f,0xc4,0x84,0x1a = csinc wzr, w4, w4, gt
-0xe9,0xa7,0x9f,0x1a = csinc w9, wzr, wzr, ge
-0xa3,0xd4,0x85,0x9a = csinc x3, x5, x5, le
-0x9f,0xc4,0x84,0x9a = csinc xzr, x4, x4, gt
-0xe9,0xa7,0x9f,0x9a = csinc x9, xzr, xzr, ge
-0xa3,0xd0,0x85,0x5a = csinv w3, w5, w5, le
-0x9f,0xc0,0x84,0x5a = csinv wzr, w4, w4, gt
-0xe9,0xa3,0x9f,0x5a = csinv w9, wzr, wzr, ge
-0xa3,0xd0,0x85,0xda = csinv x3, x5, x5, le
-0x9f,0xc0,0x84,0xda = csinv xzr, x4, x4, gt
-0xe9,0xa3,0x9f,0xda = csinv x9, xzr, xzr, ge
-0xa3,0xd4,0x85,0x5a = csneg w3, w5, w5, le
-0x9f,0xc4,0x84,0x5a = csneg wzr, w4, w4, gt
-0xe9,0xa7,0x9f,0x5a = csneg w9, wzr, wzr, ge
-0xa3,0xd4,0x85,0xda = csneg x3, x5, x5, le
-0x9f,0xc4,0x84,0xda = csneg xzr, x4, x4, gt
-0xe9,0xa7,0x9f,0xda = csneg x9, xzr, xzr, ge
+// 0xe3,0x17,0x9f,0x1a = csinc w3, wzr, wzr, ne
+// 0xe9,0x47,0x9f,0x9a = csinc x9, xzr, xzr, mi
+// 0xf4,0x03,0x9f,0x5a = csinv w20, wzr, wzr, eq
+// 0xfe,0xb3,0x9f,0xda = csinv x30, xzr, xzr, lt
+// 0xa3,0xd4,0x85,0x1a = csinc w3, w5, w5, le
+// 0x9f,0xc4,0x84,0x1a = csinc wzr, w4, w4, gt
+// 0xe9,0xa7,0x9f,0x1a = csinc w9, wzr, wzr, ge
+// 0xa3,0xd4,0x85,0x9a = csinc x3, x5, x5, le
+// 0x9f,0xc4,0x84,0x9a = csinc xzr, x4, x4, gt
+// 0xe9,0xa7,0x9f,0x9a = csinc x9, xzr, xzr, ge
+// 0xa3,0xd0,0x85,0x5a = csinv w3, w5, w5, le
+// 0x9f,0xc0,0x84,0x5a = csinv wzr, w4, w4, gt
+// 0xe9,0xa3,0x9f,0x5a = csinv w9, wzr, wzr, ge
+// 0xa3,0xd0,0x85,0xda = csinv x3, x5, x5, le
+// 0x9f,0xc0,0x84,0xda = csinv xzr, x4, x4, gt
+// 0xe9,0xa3,0x9f,0xda = csinv x9, xzr, xzr, ge
+// 0xa3,0xd4,0x85,0x5a = csneg w3, w5, w5, le
+// 0x9f,0xc4,0x84,0x5a = csneg wzr, w4, w4, gt
+// 0xe9,0xa7,0x9f,0x5a = csneg w9, wzr, wzr, ge
+// 0xa3,0xd4,0x85,0xda = csneg x3, x5, x5, le
+// 0x9f,0xc4,0x84,0xda = csneg xzr, x4, x4, gt
+// 0xe9,0xa7,0x9f,0xda = csneg x9, xzr, xzr, ge
 0xe0,0x00,0xc0,0x5a = rbit w0, w7
 0x72,0x00,0xc0,0xda = rbit x18, x3
 0x31,0x04,0xc0,0x5a = rev16 w17, w1
@@ -668,16 +668,16 @@
 0x41,0x05,0xa0,0xd4 = dcps1 #42
 0x22,0x01,0xa0,0xd4 = dcps2 #9
 0x03,0x7d,0xa0,0xd4 = dcps3 #1000
-0x01,0x00,0xa0,0xd4 = dcps1 
-0x02,0x00,0xa0,0xd4 = dcps2 
-0x03,0x00,0xa0,0xd4 = dcps3 
+0x01,0x00,0xa0,0xd4 = dcps1
+0x02,0x00,0xa0,0xd4 = dcps2
+0x03,0x00,0xa0,0xd4 = dcps3
 0xa3,0x00,0x87,0x13 = extr w3, w5, w7, #0
 0xab,0x7d,0x91,0x13 = extr w11, w13, w17, #31
 0xa3,0x3c,0xc7,0x93 = extr x3, x5, x7, #15
 0xab,0xfd,0xd1,0x93 = extr x11, x13, x17, #63
-0xf3,0x62,0xd7,0x93 = extr x19, x23, x23, #24
-0xfd,0xff,0xdf,0x93 = extr x29, xzr, xzr, #63
-0xa9,0x7d,0x8d,0x13 = extr w9, w13, w13, #31
+// 0xf3,0x62,0xd7,0x93 = extr x19, x23, x23, #24
+// 0xfd,0xff,0xdf,0x93 = extr x29, xzr, xzr, #63
+// 0xa9,0x7d,0x8d,0x13 = extr w9, w13, w13, #31
 0x60,0x20,0x25,0x1e = fcmp s3, s5
 0xe8,0x23,0x20,0x1e = fcmp s31, #0.0
 0xb0,0x23,0x3e,0x1e = fcmpe s29, s30
@@ -937,46 +937,46 @@
 0xf4,0x07,0x40,0xf9 = ldr x20, [sp, #8]
 0xff,0x03,0x40,0xf9 = ldr xzr, [sp]
 0xe2,0x03,0x40,0xb9 = ldr w2, [sp]
-0xf1,0xff,0x7f,0xb9 = ldr w17, [sp, #16380]
+// 0xf1,0xff,0x7f,0xb9 = ldr w17, [sp, #0x6660]
 0x4d,0x04,0x40,0xb9 = ldr w13, [x2, #4]
 0xa2,0x04,0x80,0xb9 = ldrsw x2, [x5, #4]
-0xf7,0xff,0xbf,0xb9 = ldrsw x23, [sp, #16380]
+// 0xf7,0xff,0xbf,0xb9 = ldrsw x23, [sp, #0x6660]
 0x82,0x00,0x40,0x79 = ldrh w2, [x4]
 0xd7,0xfc,0xff,0x79 = ldrsh w23, [x6, #8190]
 0xff,0x07,0xc0,0x79 = ldrsh wzr, [sp, #2]
 0x5d,0x04,0x80,0x79 = ldrsh x29, [x2, #2]
 0x7a,0xe4,0x41,0x39 = ldrb w26, [x3, #121]
 0x4c,0x00,0x40,0x39 = ldrb w12, [x2]
-0xfb,0xff,0xff,0x39 = ldrsb w27, [sp, #4095]
+0xfb,0xff,0xff,0x39 = ldrsb w27, [sp, #0xfff]
 0xff,0x01,0x80,0x39 = ldrsb xzr, [x15]
 0xfe,0x03,0x00,0xf9 = str x30, [sp]
-0x94,0xfc,0x3f,0xb9 = str w20, [x4, #16380]
+// 0x94,0xfc,0x3f,0xb9 = str w20, [x4, #0x6660]
 0x54,0x1d,0x00,0x79 = strh w20, [x10, #14]
 0xf1,0xff,0x3f,0x79 = strh w17, [sp, #8190]
-0x77,0xfc,0x3f,0x39 = strb w23, [x3, #4095]
+0x77,0xfc,0x3f,0x39 = strb w23, [x3, #0xfff]
 0x5f,0x00,0x00,0x39 = strb wzr, [x2]
 0xe0,0x07,0x80,0xf9 = prfm pldl1keep, [sp, #8]
-0x61,0x00,0x80,0xf9 = prfm pldl1strm, [x3, #0]
+// 0x61,0x00,0x80,0xf9 = prfm pldl1strm, [x3, #0]
 0xa2,0x08,0x80,0xf9 = prfm pldl2keep, [x5, #16]
-0x43,0x00,0x80,0xf9 = prfm pldl2strm, [x2, #0]
-0xa4,0x00,0x80,0xf9 = prfm pldl3keep, [x5, #0]
-0xc5,0x00,0x80,0xf9 = prfm pldl3strm, [x6, #0]
+// 0x43,0x00,0x80,0xf9 = prfm pldl2strm, [x2, #0]
+// 0xa4,0x00,0x80,0xf9 = prfm pldl3keep, [x5, #0]
+// 0xc5,0x00,0x80,0xf9 = prfm pldl3strm, [x6, #0]
 0xe8,0x07,0x80,0xf9 = prfm plil1keep, [sp, #8]
-0x69,0x00,0x80,0xf9 = prfm plil1strm, [x3, #0]
+// 0x69,0x00,0x80,0xf9 = prfm plil1strm, [x3, #0]
 0xaa,0x08,0x80,0xf9 = prfm plil2keep, [x5, #16]
-0x4b,0x00,0x80,0xf9 = prfm plil2strm, [x2, #0]
-0xac,0x00,0x80,0xf9 = prfm plil3keep, [x5, #0]
-0xcd,0x00,0x80,0xf9 = prfm plil3strm, [x6, #0]
+// 0x4b,0x00,0x80,0xf9 = prfm plil2strm, [x2, #0]
+// 0xac,0x00,0x80,0xf9 = prfm plil3keep, [x5, #0]
+// 0xcd,0x00,0x80,0xf9 = prfm plil3strm, [x6, #0]
 0xf0,0x07,0x80,0xf9 = prfm pstl1keep, [sp, #8]
-0x71,0x00,0x80,0xf9 = prfm pstl1strm, [x3, #0]
+// 0x71,0x00,0x80,0xf9 = prfm pstl1strm, [x3, #0]
 0xb2,0x08,0x80,0xf9 = prfm pstl2keep, [x5, #16]
-0x53,0x00,0x80,0xf9 = prfm pstl2strm, [x2, #0]
-0xb4,0x00,0x80,0xf9 = prfm pstl3keep, [x5, #0]
-0xd5,0x00,0x80,0xf9 = prfm pstl3strm, [x6, #0]
-0xef,0x03,0x80,0xf9 = prfm #15, [sp, #0]
-0xff,0xff,0x7f,0x3d = ldr b31, [sp, #4095]
+// 0x53,0x00,0x80,0xf9 = prfm pstl2strm, [x2, #0]
+// 0xb4,0x00,0x80,0xf9 = prfm pstl3keep, [x5, #0]
+// 0xd5,0x00,0x80,0xf9 = prfm pstl3strm, [x6, #0]
+// 0xef,0x03,0x80,0xf9 = prfm #15, [sp, #0]
+0xff,0xff,0x7f,0x3d = ldr b31, [sp, #0xfff]
 0x54,0xfc,0x7f,0x7d = ldr h20, [x2, #8190]
-0x6a,0xfe,0x7f,0xbd = ldr s10, [x19, #16380]
+// 0x6a,0xfe,0x7f,0xbd = ldr s10, [x19, #0x6660]
 0x43,0xfd,0x7f,0xfd = ldr d3, [x10, #32760]
 0xec,0xff,0xbf,0x3d = str q12, [sp, #65520]
 0xe3,0x6b,0x65,0x38 = ldrb w3, [sp, x5]
@@ -1024,7 +1024,7 @@
 0xf1,0xca,0x69,0xf8 = ldr x17, [x23, w9, sxtw]
 0xd2,0xca,0x6a,0xf8 = ldr x18, [x22, w10, sxtw]
 0xb3,0xda,0x3f,0xfc = str d19, [x21, wzr, sxtw #3]
-0x06,0x68,0xa5,0xf8 = prfm #6, [x0, x5, lsl #0]
+// 0x06,0x68,0xa5,0xf8 = prfm #6, [x0, x5, lsl #0]
 0xe3,0x6b,0xe5,0x3c = ldr q3, [sp, x5]
 0x69,0x6b,0xe6,0x3c = ldr q9, [x27, x6]
 0xca,0x7b,0xe7,0x3c = ldr q10, [x30, x7, lsl #4]
@@ -1272,11 +1272,11 @@
 0xc3,0xc8,0x03,0x52 = eor w3, w6, #0xe0e0e0e0
 0xff,0xc7,0x00,0x52 = eor wsp, wzr, #0x3030303
 0x30,0xc6,0x01,0x52 = eor w16, w17, #0x81818181
-0x5f,0xe6,0x02,0x72 = ands wzr, w18, #0xcccccccc
+// 0x5f,0xe6,0x02,0x72 = ands wzr, w18, #0xcccccccc
 0x93,0xe6,0x00,0x72 = ands w19, w20, #0x33333333
 0xd5,0xe6,0x01,0x72 = ands w21, w22, #0x99999999
-0x7f,0xf0,0x01,0x72 = ands wzr, w3, #0xaaaaaaaa
-0xff,0xf3,0x00,0x72 = ands wzr, wzr, #0x55555555
+// 0x7f,0xf0,0x01,0x72 = ands wzr, w3, #0xaaaaaaaa
+// 0xff,0xf3,0x00,0x72 = ands wzr, wzr, #0x55555555
 0xa3,0x84,0x66,0xd2 = eor x3, x5, #0xffffffffc000000
 0x49,0xb9,0x40,0x92 = and x9, x10, #0x7fffffffffff
 0x8b,0x31,0x41,0xb2 = orr x11, x12, #0x8000000000000fff
@@ -1289,13 +1289,14 @@
 0xc3,0xc8,0x03,0xd2 = eor x3, x6, #0xe0e0e0e0e0e0e0e0
 0xff,0xc7,0x00,0xd2 = eor sp, xzr, #0x303030303030303
 0x30,0xc6,0x01,0xd2 = eor x16, x17, #0x8181818181818181
-0x5f,0xe6,0x02,0xf2 = ands xzr, x18, #0xcccccccccccccccc
+// 0x5f,0xe6,0x02,0xf2 = ands xzr, x18, #0xcccccccccccccccc
 0x93,0xe6,0x00,0xf2 = ands x19, x20, #0x3333333333333333
 0xd5,0xe6,0x01,0xf2 = ands x21, x22, #0x9999999999999999
-0x7f,0xf0,0x01,0xf2 = ands xzr, x3, #0xaaaaaaaaaaaaaaaa
-0xff,0xf3,0x00,0xf2 = ands xzr, xzr, #0x5555555555555555
-0xe3,0x8f,0x00,0x32 = orr w3, wzr, #0xf000f
-0xea,0xf3,0x01,0xb2 = orr x10, xzr, #0xaaaaaaaaaaaaaaaa
+// 0x7f,0xf0,0x01,0xf2 = ands xzr, x3, #0xaaaaaaaaaaaaaaaa
+// 0xff,0xf3,0x00,0xf2 = ands xzr, xzr, #0x5555555555555555
+0xe3,0x8f,0x00,0x32 = mov w3, #0xf000f
+// 0xea,0xf3,0x01,0xb2 = orr x10, xzr, #0xaaaaaaaaaaaaaaaa
+0xea,0xf3,0x01,0xb2 = mov x10, #0xaaaaaaaaaaaaaaaa
 0xec,0x02,0x15,0x0a = and w12, w23, w21
 0xf0,0x05,0x01,0x0a = and w16, w15, w1, lsl #1
 0x89,0x7c,0x0a,0x0a = and w9, w4, w10, lsl #31
@@ -1324,10 +1325,10 @@
 0xe3,0x03,0x1f,0xaa = mov x3, xzr
 0xff,0x03,0x02,0x2a = mov wzr, w2
 0xe3,0x03,0x05,0x2a = mov w3, w5
-0xe1,0xff,0x9f,0x52 = movz w1, #65535
+0xe1,0xff,0x9f,0x52 = mov w1, #0xffff
 0x02,0x00,0xa0,0x52 = movz w2, #0, lsl #16
-0x42,0x9a,0x80,0x12 = movn w2, #1234
-0x42,0x9a,0xc0,0xd2 = movz x2, #1234, lsl #32
+0x42,0x9a,0x80,0x12 = mov w2, #-0x4d3
+// 0x42,0x9a,0xc0,0xd2 = movz x2, #1234, lsl #32
 0x3f,0x1c,0xe2,0xf2 = movk xzr, #4321, lsl #48
 0x1e,0x00,0x00,0xb0 = adrp x30, #4096
 0x14,0x00,0x00,0x10 = adr x20, #0
@@ -1337,20 +1338,23 @@
 0x02,0x00,0x80,0x10 = adr x2, #-1048576
 0xe9,0xff,0x7f,0xf0 = adrp x9, #4294963200
 0x14,0x00,0x80,0x90 = adrp x20, #-4294967296
-0x1f,0x20,0x03,0xd5 = nop 
+0x1f,0x20,0x03,0xd5 = nop
 0xff,0x2f,0x03,0xd5 = hint #127
-0x1f,0x20,0x03,0xd5 = nop 
-0x3f,0x20,0x03,0xd5 = yield 
-0x5f,0x20,0x03,0xd5 = wfe 
-0x7f,0x20,0x03,0xd5 = wfi 
-0x9f,0x20,0x03,0xd5 = sev 
-0xbf,0x20,0x03,0xd5 = sevl 
-0x5f,0x3f,0x03,0xd5 = clrex 
+0x1f,0x20,0x03,0xd5 = nop
+0x3f,0x20,0x03,0xd5 = yield
+0x5f,0x20,0x03,0xd5 = wfe
+0x7f,0x20,0x03,0xd5 = wfi
+0x9f,0x20,0x03,0xd5 = sev
+0xbf,0x20,0x03,0xd5 = sevl
+0x5f,0x3f,0x03,0xd5 = clrex
 0x5f,0x30,0x03,0xd5 = clrex #0
 0x5f,0x37,0x03,0xd5 = clrex #7
-0x5f,0x3f,0x03,0xd5 = clrex 
-0x9f,0x30,0x03,0xd5 = dsb #0
-0x9f,0x3c,0x03,0xd5 = dsb #12
+0x5f,0x3f,0x03,0xd5 = clrex
+// 0x9f,0x30,0x03,0xd5 = dsb #0
+0x9f,0x30,0x03,0xd5 = ssbb
+// 0x9f,0x3c,0x03,0xd5 = dsb #12
+0x9f,0x3c,0x03,0xd5 = dfb
+0x9f,0x38,0x03,0xd5 = dsb #8
 0x9f,0x3f,0x03,0xd5 = dsb sy
 0x9f,0x31,0x03,0xd5 = dsb oshld
 0x9f,0x32,0x03,0xd5 = dsb oshst
@@ -1379,14 +1383,16 @@
 0xbf,0x3d,0x03,0xd5 = dmb ld
 0xbf,0x3e,0x03,0xd5 = dmb st
 0xbf,0x3f,0x03,0xd5 = dmb sy
-0xdf,0x3f,0x03,0xd5 = isb 
-0xdf,0x3f,0x03,0xd5 = isb 
+0xdf,0x3f,0x03,0xd5 = isb
+0xdf,0x3f,0x03,0xd5 = isb
 0xdf,0x3c,0x03,0xd5 = isb #12
 0xbf,0x40,0x00,0xd5 = msr spsel, #0
 0xdf,0x4f,0x03,0xd5 = msr daifset, #15
 0xff,0x4c,0x03,0xd5 = msr daifclr, #12
+0x9f,0x40,0x00,0xd5 = msr pan, #0
+0x7f,0x40,0x00,0xd5 = msr uao, #0
 0xe5,0x59,0x0f,0xd5 = sys #7, c5, c9, #7, x5
-0x5f,0xff,0x08,0xd5 = sys #0, c15, c15, #2, xzr
+// 0x5f,0xff,0x08,0xd5 = sys #0, c15, c15, #2, xzr
 0xe9,0x59,0x2f,0xd5 = sysl x9, #7, c5, c9, #7
 0x41,0xff,0x28,0xd5 = sysl x1, #0, c15, c15, #2
 0x1f,0x71,0x08,0xd5 = ic ialluis
@@ -1564,7 +1570,7 @@
 0x0c,0x42,0x18,0xd5 = msr spsel, x12
 0x0c,0x42,0x1b,0xd5 = msr nzcv, x12
 0x2c,0x42,0x1b,0xd5 = msr daif, x12
-0x4c,0x42,0x18,0xd5 = msr currentel, x12
+// 0x4c,0x42,0x18,0xd5 = msr currentel, x12
 0x0c,0x43,0x1c,0xd5 = msr spsr_irq, x12
 0x2c,0x43,0x1c,0xd5 = msr spsr_abt, x12
 0x4c,0x43,0x1c,0xd5 = msr spsr_und, x12
@@ -1575,9 +1581,11 @@
 0x2c,0x45,0x1b,0xd5 = msr dlr_el0, x12
 0x2c,0x50,0x1c,0xd5 = msr ifsr32_el2, x12
 0x0c,0x51,0x18,0xd5 = msr afsr0_el1, x12
+
 0x0c,0x51,0x1c,0xd5 = msr afsr0_el2, x12
 0x0c,0x51,0x1e,0xd5 = msr afsr0_el3, x12
 0x2c,0x51,0x18,0xd5 = msr afsr1_el1, x12
+0x2c,0x51,0x1d,0xd5 = msr afsr1_el12, x12
 0x2c,0x51,0x1c,0xd5 = msr afsr1_el2, x12
 0x2c,0x51,0x1e,0xd5 = msr afsr1_el3, x12
 0x0c,0x52,0x18,0xd5 = msr esr_el1, x12
@@ -1633,6 +1641,7 @@
 0x4c,0xe2,0x1c,0xd5 = msr cnthp_cval_el2, x12
 0x4c,0xe2,0x1f,0xd5 = msr cntps_cval_el1, x12
 0x0c,0xe3,0x1b,0xd5 = msr cntv_tval_el0, x12
+0x0c,0xe3,0x1d,0xd5 = msr cntv_tval_el02, x12
 0x2c,0xe3,0x1b,0xd5 = msr cntv_ctl_el0, x12
 0x4c,0xe3,0x1b,0xd5 = msr cntv_cval_el0, x12
 0x0c,0xe8,0x1b,0xd5 = msr pmevcntr0_el0, x12
@@ -1698,6 +1707,8 @@
 0x8c,0xef,0x1b,0xd5 = msr pmevtyper28_el0, x12
 0xac,0xef,0x1b,0xd5 = msr pmevtyper29_el0, x12
 0xcc,0xef,0x1b,0xd5 = msr pmevtyper30_el0, x12
+0x69,0x42,0x38,0xd5 = mrs x9, pan
+0x89,0x42,0x38,0xd5 = mrs x9, uao
 0x09,0x00,0x32,0xd5 = mrs x9, teecr32_el1
 0x49,0x00,0x30,0xd5 = mrs x9, osdtrrx_el1
 0x09,0x01,0x33,0xd5 = mrs x9, mdccsr_el0
@@ -1799,6 +1810,7 @@
 0xa9,0x01,0x38,0xd5 = mrs x9, id_mmfr1_el1
 0xc9,0x01,0x38,0xd5 = mrs x9, id_mmfr2_el1
 0xe9,0x01,0x38,0xd5 = mrs x9, id_mmfr3_el1
+0xc9,0x02,0x38,0xd5 = mrs x9, id_mmfr4_el1
 0x09,0x02,0x38,0xd5 = mrs x9, id_isar0_el1
 0x29,0x02,0x38,0xd5 = mrs x9, id_isar1_el1
 0x49,0x02,0x38,0xd5 = mrs x9, id_isar2_el1
@@ -1818,13 +1830,21 @@
 0x29,0x06,0x38,0xd5 = mrs x9, id_aa64isar1_el1
 0x09,0x07,0x38,0xd5 = mrs x9, id_aa64mmfr0_el1
 0x29,0x07,0x38,0xd5 = mrs x9, id_aa64mmfr1_el1
+0x49,0x07,0x38,0xd5 = mrs x9, id_aa64mmfr2_el1
+0x69,0xa4,0x38,0xd5 = mrs x9, lorc_el1
+0x29,0xa4,0x38,0xd5 = mrs x9, lorea_el1
+0xe9,0xa4,0x38,0xd5 = mrs x9, lorid_el1
+0x49,0xa4,0x38,0xd5 = mrs x9, lorn_el1
+0x09,0xa4,0x38,0xd5 = mrs x9, lorsa_el1
 0x09,0x10,0x38,0xd5 = mrs x9, sctlr_el1
+0x09,0x10,0x3d,0xd5 = mrs x9, sctlr_el12
 0x09,0x10,0x3c,0xd5 = mrs x9, sctlr_el2
 0x09,0x10,0x3e,0xd5 = mrs x9, sctlr_el3
 0x29,0x10,0x38,0xd5 = mrs x9, actlr_el1
 0x29,0x10,0x3c,0xd5 = mrs x9, actlr_el2
 0x29,0x10,0x3e,0xd5 = mrs x9, actlr_el3
 0x49,0x10,0x38,0xd5 = mrs x9, cpacr_el1
+0x49,0x10,0x3d,0xd5 = mrs x9, cpacr_el12
 0x09,0x11,0x3c,0xd5 = mrs x9, hcr_el2
 0x09,0x11,0x3e,0xd5 = mrs x9, scr_el3
 0x29,0x11,0x3c,0xd5 = mrs x9, mdcr_el2
@@ -1835,19 +1855,25 @@
 0xe9,0x11,0x3c,0xd5 = mrs x9, hacr_el2
 0x29,0x13,0x3e,0xd5 = mrs x9, mdcr_el3
 0x09,0x20,0x38,0xd5 = mrs x9, ttbr0_el1
+0x09,0x20,0x3d,0xd5 = mrs x9, ttbr0_el12
 0x09,0x20,0x3c,0xd5 = mrs x9, ttbr0_el2
 0x09,0x20,0x3e,0xd5 = mrs x9, ttbr0_el3
 0x29,0x20,0x38,0xd5 = mrs x9, ttbr1_el1
+0x29,0x20,0x3d,0xd5 = mrs x9, ttbr1_el12
+0x29,0x20,0x3c,0xd5 = mrs x9, ttbr1_el2
 0x49,0x20,0x38,0xd5 = mrs x9, tcr_el1
+0x49,0x20,0x3d,0xd5 = mrs x9, tcr_el12
 0x49,0x20,0x3c,0xd5 = mrs x9, tcr_el2
 0x49,0x20,0x3e,0xd5 = mrs x9, tcr_el3
 0x09,0x21,0x3c,0xd5 = mrs x9, vttbr_el2
 0x49,0x21,0x3c,0xd5 = mrs x9, vtcr_el2
 0x09,0x30,0x3c,0xd5 = mrs x9, dacr32_el2
 0x09,0x40,0x38,0xd5 = mrs x9, spsr_el1
+0x09,0x40,0x3d,0xd5 = mrs x9, spsr_el12
 0x09,0x40,0x3c,0xd5 = mrs x9, spsr_el2
 0x09,0x40,0x3e,0xd5 = mrs x9, spsr_el3
 0x29,0x40,0x38,0xd5 = mrs x9, elr_el1
+0x29,0x40,0x3d,0xd5 = mrs x9, elr_el12
 0x29,0x40,0x3c,0xd5 = mrs x9, elr_el2
 0x29,0x40,0x3e,0xd5 = mrs x9, elr_el3
 0x09,0x41,0x38,0xd5 = mrs x9, sp_el0
@@ -1867,16 +1893,19 @@
 0x29,0x45,0x3b,0xd5 = mrs x9, dlr_el0
 0x29,0x50,0x3c,0xd5 = mrs x9, ifsr32_el2
 0x09,0x51,0x38,0xd5 = mrs x9, afsr0_el1
+0x09,0x51,0x3d,0xd5 = mrs x9, afsr0_el12
 0x09,0x51,0x3c,0xd5 = mrs x9, afsr0_el2
 0x09,0x51,0x3e,0xd5 = mrs x9, afsr0_el3
 0x29,0x51,0x38,0xd5 = mrs x9, afsr1_el1
 0x29,0x51,0x3c,0xd5 = mrs x9, afsr1_el2
 0x29,0x51,0x3e,0xd5 = mrs x9, afsr1_el3
 0x09,0x52,0x38,0xd5 = mrs x9, esr_el1
+0x09,0x52,0x3d,0xd5 = mrs x9, esr_el12
 0x09,0x52,0x3c,0xd5 = mrs x9, esr_el2
 0x09,0x52,0x3e,0xd5 = mrs x9, esr_el3
 0x09,0x53,0x3c,0xd5 = mrs x9, fpexc32_el2
 0x09,0x60,0x38,0xd5 = mrs x9, far_el1
+0x09,0x60,0x3d,0xd5 = mrs x9, far_el12
 0x09,0x60,0x3c,0xd5 = mrs x9, far_el2
 0x09,0x60,0x3e,0xd5 = mrs x9, far_el3
 0x89,0x60,0x3c,0xd5 = mrs x9, hpfar_el2
@@ -1896,12 +1925,15 @@
 0x49,0x9e,0x38,0xd5 = mrs x9, pmintenclr_el1
 0x69,0x9e,0x3b,0xd5 = mrs x9, pmovsset_el0
 0x09,0xa2,0x38,0xd5 = mrs x9, mair_el1
+0x09,0xa2,0x3d,0xd5 = mrs x9, mair_el12
 0x09,0xa2,0x3c,0xd5 = mrs x9, mair_el2
 0x09,0xa2,0x3e,0xd5 = mrs x9, mair_el3
 0x09,0xa3,0x38,0xd5 = mrs x9, amair_el1
+0x09,0xa3,0x3d,0xd5 = mrs x9, amair_el12
 0x09,0xa3,0x3c,0xd5 = mrs x9, amair_el2
 0x09,0xa3,0x3e,0xd5 = mrs x9, amair_el3
 0x09,0xc0,0x38,0xd5 = mrs x9, vbar_el1
+0x09,0xc0,0x3d,0xd5 = mrs x9, vbar_el12
 0x09,0xc0,0x3c,0xd5 = mrs x9, vbar_el2
 0x09,0xc0,0x3e,0xd5 = mrs x9, vbar_el3
 0x29,0xc0,0x38,0xd5 = mrs x9, rvbar_el1
@@ -1912,6 +1944,8 @@
 0x49,0xc0,0x3e,0xd5 = mrs x9, rmr_el3
 0x09,0xc1,0x38,0xd5 = mrs x9, isr_el1
 0x29,0xd0,0x38,0xd5 = mrs x9, contextidr_el1
+0x29,0xd0,0x3d,0xd5 = mrs x9, contextidr_el12
+// 0x29,0xd0,0x3c,0xd5 = mrs x9, contextdir_el2
 0x49,0xd0,0x3b,0xd5 = mrs x9, tpidr_el0
 0x49,0xd0,0x3c,0xd5 = mrs x9, tpidr_el2
 0x49,0xd0,0x3e,0xd5 = mrs x9, tpidr_el3
@@ -1922,19 +1956,27 @@
 0x49,0xe0,0x3b,0xd5 = mrs x9, cntvct_el0
 0x69,0xe0,0x3c,0xd5 = mrs x9, cntvoff_el2
 0x09,0xe1,0x38,0xd5 = mrs x9, cntkctl_el1
+0x09,0xe1,0x3d,0xd5 = mrs x9, cntkctl_el12
 0x09,0xe1,0x3c,0xd5 = mrs x9, cnthctl_el2
 0x09,0xe2,0x3b,0xd5 = mrs x9, cntp_tval_el0
+0x09,0xe2,0x3d,0xd5 = mrs x9, cntp_tval_el02
 0x09,0xe2,0x3c,0xd5 = mrs x9, cnthp_tval_el2
 0x09,0xe2,0x3f,0xd5 = mrs x9, cntps_tval_el1
 0x29,0xe2,0x3b,0xd5 = mrs x9, cntp_ctl_el0
 0x29,0xe2,0x3c,0xd5 = mrs x9, cnthp_ctl_el2
 0x29,0xe2,0x3f,0xd5 = mrs x9, cntps_ctl_el1
 0x49,0xe2,0x3b,0xd5 = mrs x9, cntp_cval_el0
+0x49,0xe2,0x3d,0xd5 = mrs x9, cntp_cval_el02
 0x49,0xe2,0x3c,0xd5 = mrs x9, cnthp_cval_el2
+// 0x20,0xe3,0x3c,0xd5 = mrs x9, cnthv_ctl_el2
+0x49,0xe3,0x3c,0xd5 = mrs x9, cnthv_cval_el2
+0x09,0xe3,0x3c,0xd5 = mrs x9, cnthv_tval_el2
 0x49,0xe2,0x3f,0xd5 = mrs x9, cntps_cval_el1
 0x09,0xe3,0x3b,0xd5 = mrs x9, cntv_tval_el0
 0x29,0xe3,0x3b,0xd5 = mrs x9, cntv_ctl_el0
+0x29,0xe3,0x3d,0xd5 = mrs x9, cntv_ctl_el02
 0x49,0xe3,0x3b,0xd5 = mrs x9, cntv_cval_el0
+0x49,0xe3,0x3d,0xd5 = mrs x9, cntv_cval_el02
 0x09,0xe8,0x3b,0xd5 = mrs x9, pmevcntr0_el0
 0x29,0xe8,0x3b,0xd5 = mrs x9, pmevcntr1_el0
 0x49,0xe8,0x3b,0xd5 = mrs x9, pmevcntr2_el0
@@ -1998,6 +2040,19 @@
 0x89,0xef,0x3b,0xd5 = mrs x9, pmevtyper28_el0
 0xa9,0xef,0x3b,0xd5 = mrs x9, pmevtyper29_el0
 0xc9,0xef,0x3b,0xd5 = mrs x9, pmevtyper30_el0
+0xe9,0x99,0x38,0xd5 = mrs x9, pmsidr_el1
+0xe9,0x9a,0x38,0xd5 = mrs x9, pmbidr_el1
+0x09,0x9a,0x38,0xd5 = mrs x9, pmblimitr_el1
+0x29,0x9a,0x38,0xd5 = mrs x9, pmbptr_el1
+0x69,0x9a,0x38,0xd5 = mrs x9, pmbsr_el1
+0x09,0x99,0x38,0xd5 = mrs x9, pmscr_el1
+0x09,0x99,0x3d,0xd5 = mrs x9, pmscr_el12
+0x09,0x99,0x3c,0xd5 = mrs x9, pmscr_el2
+0x49,0x99,0x38,0xd5 = mrs x9, pmsicr_el1
+0x69,0x99,0x38,0xd5 = mrs x9, pmsirr_el1
+0x89,0x99,0x38,0xd5 = mrs x9, pmsfcr_el1
+0xa9,0x99,0x38,0xd5 = mrs x9, pmsevfr_el1
+0xc9,0x99,0x38,0xd5 = mrs x9, pmslatfr_el1
 0xac,0xf1,0x3f,0xd5 = mrs x12, s3_7_c15_c1_5
 0xed,0xbf,0x3a,0xd5 = mrs x13, s3_2_c11_c15_7
 0x0c,0xf0,0x18,0xd5 = msr s3_0_c15_c0_0, x12
@@ -2009,6 +2064,6 @@
 0x80,0x02,0x1f,0xd6 = br x20
 0xe0,0x03,0x3f,0xd6 = blr xzr
 0x40,0x01,0x5f,0xd6 = ret x10
-0xc0,0x03,0x5f,0xd6 = ret 
-0xe0,0x03,0x9f,0xd6 = eret 
-0xe0,0x03,0xbf,0xd6 = drps 
+0xc0,0x03,0x5f,0xd6 = ret
+0xe0,0x03,0x9f,0xd6 = eret
+0xe0,0x03,0xbf,0xd6 = drps
