@@ -88,8 +88,8 @@
 0xe3,0x00,0x0f,0xff,0x7f,0xcd = chf %r0, 524287
 0xe3,0x00,0x10,0x00,0x00,0xcd = chf %r0, 0(%r1)
 0xe3,0x00,0xf0,0x00,0x00,0xcd = chf %r0, 0(%r15)
-0xe3,0x01,0xff,0xff,0x7f,0xcd = chf %r0, 524287(%r1,%r15)
-0xe3,0x0f,0x1f,0xff,0x7f,0xcd = chf %r0, 524287(%r15,%r1)
+0xe3,0x01,0xff,0xff,0x7f,0xcd = chf %r0, 524287(%r1, %r15)
+0xe3,0x0f,0x1f,0xff,0x7f,0xcd = chf %r0, 524287(%r15, %r1)
 0xe3,0xf0,0x00,0x00,0x00,0xcd = chf %r15, 0
 0xcc,0x0d,0x80,0x00,0x00,0x00 = cih %r0, -2147483648
 0xcc,0x0d,0xff,0xff,0xff,0xff = cih %r0, -1
@@ -140,8 +140,8 @@
 0xe3,0x00,0x0f,0xff,0x7f,0xcf = clhf %r0, 524287
 0xe3,0x00,0x10,0x00,0x00,0xcf = clhf %r0, 0(%r1)
 0xe3,0x00,0xf0,0x00,0x00,0xcf = clhf %r0, 0(%r15)
-0xe3,0x01,0xff,0xff,0x7f,0xcf = clhf %r0, 524287(%r1,%r15)
-0xe3,0x0f,0x1f,0xff,0x7f,0xcf = clhf %r0, 524287(%r15,%r1)
+0xe3,0x01,0xff,0xff,0x7f,0xcf = clhf %r0, 524287(%r1, %r15)
+0xe3,0x0f,0x1f,0xff,0x7f,0xcf = clhf %r0, 524287(%r15, %r1)
 0xe3,0xf0,0x00,0x00,0x00,0xcf = clhf %r15, 0
 0xcc,0x0f,0x00,0x00,0x00,0x00 = clih %r0, 0
 0xcc,0x0f,0x00,0x00,0x00,0x01 = clih %r0, 1
@@ -159,24 +159,24 @@
 0xb3,0xa2,0xf0,0x00 = cxlgbr %f0, 15, %r0, 0
 0xb3,0xa2,0x5a,0x49 = cxlgbr %f4, 5, %r9, 10
 0xb3,0xa2,0x00,0xd0 = cxlgbr %f13, 0, %r0, 0
-0xb3,0x5f,0x00,0x00 = fidbra %f0, 0, %f0, 0
+// 0xb3,0x5f,0x00,0x00 = fidbra %f0, 0, %f0, 0
 0xb3,0x5f,0x0f,0x00 = fidbra %f0, 0, %f0, 15
-0xb3,0x5f,0x00,0x0f = fidbra %f0, 0, %f15, 0
-0xb3,0x5f,0xf0,0x00 = fidbra %f0, 15, %f0, 0
+// 0xb3,0x5f,0x00,0x0f = fidbra %f0, 0, %f15, 0
+// 0xb3,0x5f,0xf0,0x00 = fidbra %f0, 15, %f0, 0
 0xb3,0x5f,0x57,0x46 = fidbra %f4, 5, %f6, 7
-0xb3,0x5f,0x00,0xf0 = fidbra %f15, 0, %f0, 0
-0xb3,0x57,0x00,0x00 = fiebra %f0, 0, %f0, 0
+// 0xb3,0x5f,0x00,0xf0 = fidbra %f15, 0, %f0, 0
+// 0xb3,0x57,0x00,0x00 = fiebra %f0, 0, %f0, 0
 0xb3,0x57,0x0f,0x00 = fiebra %f0, 0, %f0, 15
-0xb3,0x57,0x00,0x0f = fiebra %f0, 0, %f15, 0
-0xb3,0x57,0xf0,0x00 = fiebra %f0, 15, %f0, 0
+// 0xb3,0x57,0x00,0x0f = fiebra %f0, 0, %f15, 0
+// 0xb3,0x57,0xf0,0x00 = fiebra %f0, 15, %f0, 0
 0xb3,0x57,0x57,0x46 = fiebra %f4, 5, %f6, 7
-0xb3,0x57,0x00,0xf0 = fiebra %f15, 0, %f0, 0
-0xb3,0x47,0x00,0x00 = fixbra %f0, 0, %f0, 0
+// 0xb3,0x57,0x00,0xf0 = fiebra %f15, 0, %f0, 0
+// 0xb3,0x47,0x00,0x00 = fixbra %f0, 0, %f0, 0
 0xb3,0x47,0x0f,0x00 = fixbra %f0, 0, %f0, 15
-0xb3,0x47,0x00,0x0d = fixbra %f0, 0, %f13, 0
-0xb3,0x47,0xf0,0x00 = fixbra %f0, 15, %f0, 0
+// 0xb3,0x47,0x00,0x0d = fixbra %f0, 0, %f13, 0
+// 0xb3,0x47,0xf0,0x00 = fixbra %f0, 15, %f0, 0
 0xb3,0x47,0x59,0x48 = fixbra %f4, 5, %f8, 9
-0xb3,0x47,0x00,0xd0 = fixbra %f13, 0, %f0, 0
+// 0xb3,0x47,0x00,0xd0 = fixbra %f13, 0, %f0, 0
 0xeb,0x00,0x00,0x00,0x80,0xf8 = laa %r0, %r0, -524288
 0xeb,0x00,0x0f,0xff,0xff,0xf8 = laa %r0, %r0, -1
 0xeb,0x00,0x00,0x00,0x00,0xf8 = laa %r0, %r0, 0
@@ -294,8 +294,8 @@
 0xe3,0x00,0x0f,0xff,0x7f,0xc0 = lbh %r0, 524287
 0xe3,0x00,0x10,0x00,0x00,0xc0 = lbh %r0, 0(%r1)
 0xe3,0x00,0xf0,0x00,0x00,0xc0 = lbh %r0, 0(%r15)
-0xe3,0x01,0xff,0xff,0x7f,0xc0 = lbh %r0, 524287(%r1,%r15)
-0xe3,0x0f,0x1f,0xff,0x7f,0xc0 = lbh %r0, 524287(%r15,%r1)
+0xe3,0x01,0xff,0xff,0x7f,0xc0 = lbh %r0, 524287(%r1, %r15)
+0xe3,0x0f,0x1f,0xff,0x7f,0xc0 = lbh %r0, 524287(%r15, %r1)
 0xe3,0xf0,0x00,0x00,0x00,0xc0 = lbh %r15, 0
 0xe3,0x00,0x00,0x00,0x80,0xca = lfh %r0, -524288
 0xe3,0x00,0x0f,0xff,0xff,0xca = lfh %r0, -1
@@ -304,8 +304,8 @@
 0xe3,0x00,0x0f,0xff,0x7f,0xca = lfh %r0, 524287
 0xe3,0x00,0x10,0x00,0x00,0xca = lfh %r0, 0(%r1)
 0xe3,0x00,0xf0,0x00,0x00,0xca = lfh %r0, 0(%r15)
-0xe3,0x01,0xff,0xff,0x7f,0xca = lfh %r0, 524287(%r1,%r15)
-0xe3,0x0f,0x1f,0xff,0x7f,0xca = lfh %r0, 524287(%r15,%r1)
+0xe3,0x01,0xff,0xff,0x7f,0xca = lfh %r0, 524287(%r1, %r15)
+0xe3,0x0f,0x1f,0xff,0x7f,0xca = lfh %r0, 524287(%r15, %r1)
 0xe3,0xf0,0x00,0x00,0x00,0xca = lfh %r15, 0
 0xe3,0x00,0x00,0x00,0x80,0xc4 = lhh %r0, -524288
 0xe3,0x00,0x0f,0xff,0xff,0xc4 = lhh %r0, -1
@@ -314,8 +314,8 @@
 0xe3,0x00,0x0f,0xff,0x7f,0xc4 = lhh %r0, 524287
 0xe3,0x00,0x10,0x00,0x00,0xc4 = lhh %r0, 0(%r1)
 0xe3,0x00,0xf0,0x00,0x00,0xc4 = lhh %r0, 0(%r15)
-0xe3,0x01,0xff,0xff,0x7f,0xc4 = lhh %r0, 524287(%r1,%r15)
-0xe3,0x0f,0x1f,0xff,0x7f,0xc4 = lhh %r0, 524287(%r15,%r1)
+0xe3,0x01,0xff,0xff,0x7f,0xc4 = lhh %r0, 524287(%r1, %r15)
+0xe3,0x0f,0x1f,0xff,0x7f,0xc4 = lhh %r0, 524287(%r15, %r1)
 0xe3,0xf0,0x00,0x00,0x00,0xc4 = lhh %r15, 0
 0xe3,0x00,0x00,0x00,0x80,0xc2 = llch %r0, -524288
 0xe3,0x00,0x0f,0xff,0xff,0xc2 = llch %r0, -1
@@ -324,8 +324,8 @@
 0xe3,0x00,0x0f,0xff,0x7f,0xc2 = llch %r0, 524287
 0xe3,0x00,0x10,0x00,0x00,0xc2 = llch %r0, 0(%r1)
 0xe3,0x00,0xf0,0x00,0x00,0xc2 = llch %r0, 0(%r15)
-0xe3,0x01,0xff,0xff,0x7f,0xc2 = llch %r0, 524287(%r1,%r15)
-0xe3,0x0f,0x1f,0xff,0x7f,0xc2 = llch %r0, 524287(%r15,%r1)
+0xe3,0x01,0xff,0xff,0x7f,0xc2 = llch %r0, 524287(%r1, %r15)
+0xe3,0x0f,0x1f,0xff,0x7f,0xc2 = llch %r0, 524287(%r15, %r1)
 0xe3,0xf0,0x00,0x00,0x00,0xc2 = llch %r15, 0
 0xe3,0x00,0x00,0x00,0x80,0xc6 = llhh %r0, -524288
 0xe3,0x00,0x0f,0xff,0xff,0xc6 = llhh %r0, -1
@@ -334,8 +334,8 @@
 0xe3,0x00,0x0f,0xff,0x7f,0xc6 = llhh %r0, 524287
 0xe3,0x00,0x10,0x00,0x00,0xc6 = llhh %r0, 0(%r1)
 0xe3,0x00,0xf0,0x00,0x00,0xc6 = llhh %r0, 0(%r15)
-0xe3,0x01,0xff,0xff,0x7f,0xc6 = llhh %r0, 524287(%r1,%r15)
-0xe3,0x0f,0x1f,0xff,0x7f,0xc6 = llhh %r0, 524287(%r15,%r1)
+0xe3,0x01,0xff,0xff,0x7f,0xc6 = llhh %r0, 524287(%r1, %r15)
+0xe3,0x0f,0x1f,0xff,0x7f,0xc6 = llhh %r0, 524287(%r15, %r1)
 0xe3,0xf0,0x00,0x00,0x00,0xc6 = llhh %r15, 0
 0xeb,0x00,0x00,0x00,0x00,0xf2 = loc %r0, 0, 0
 0xeb,0x0f,0x00,0x00,0x00,0xf2 = loc %r0, 0, 15
@@ -344,7 +344,7 @@
 0xeb,0x00,0x10,0x00,0x00,0xf2 = loc %r0, 0(%r1), 0
 0xeb,0x00,0xf0,0x00,0x00,0xf2 = loc %r0, 0(%r15), 0
 0xeb,0xf0,0x00,0x00,0x00,0xf2 = loc %r15, 0, 0
-0xeb,0x13,0x2f,0xff,0x00,0xf2 = loc %r1, 4095(%r2), 3
+// 0xeb,0x13,0x2f,0xff,0x00,0xf2 = loc %r1, 4095(%r2), 3
 0xeb,0x11,0x30,0x02,0x00,0xf2 = loco %r1, 2(%r3)
 0xeb,0x12,0x30,0x02,0x00,0xf2 = loch %r1, 2(%r3)
 0xeb,0x13,0x30,0x02,0x00,0xf2 = locnle %r1, 2(%r3)
@@ -366,7 +366,7 @@
 0xeb,0x00,0x10,0x00,0x00,0xe2 = locg %r0, 0(%r1), 0
 0xeb,0x00,0xf0,0x00,0x00,0xe2 = locg %r0, 0(%r15), 0
 0xeb,0xf0,0x00,0x00,0x00,0xe2 = locg %r15, 0, 0
-0xeb,0x13,0x2f,0xff,0x00,0xe2 = locg %r1, 4095(%r2), 3
+// 0xeb,0x13,0x2f,0xff,0x00,0xe2 = locg %r1, 4095(%r2), 3
 0xeb,0x11,0x30,0x02,0x00,0xe2 = locgo %r1, 2(%r3)
 0xeb,0x12,0x30,0x02,0x00,0xe2 = locgh %r1, 2(%r3)
 0xeb,0x13,0x30,0x02,0x00,0xe2 = locgnle %r1, 2(%r3)
@@ -510,8 +510,8 @@
 0xe3,0x00,0x0f,0xff,0x7f,0xc3 = stch %r0, 524287
 0xe3,0x00,0x10,0x00,0x00,0xc3 = stch %r0, 0(%r1)
 0xe3,0x00,0xf0,0x00,0x00,0xc3 = stch %r0, 0(%r15)
-0xe3,0x01,0xff,0xff,0x7f,0xc3 = stch %r0, 524287(%r1,%r15)
-0xe3,0x0f,0x1f,0xff,0x7f,0xc3 = stch %r0, 524287(%r15,%r1)
+0xe3,0x01,0xff,0xff,0x7f,0xc3 = stch %r0, 524287(%r1, %r15)
+0xe3,0x0f,0x1f,0xff,0x7f,0xc3 = stch %r0, 524287(%r15, %r1)
 0xe3,0xf0,0x00,0x00,0x00,0xc3 = stch %r15, 0
 0xe3,0x00,0x00,0x00,0x80,0xc7 = sthh %r0, -524288
 0xe3,0x00,0x0f,0xff,0xff,0xc7 = sthh %r0, -1
@@ -520,8 +520,8 @@
 0xe3,0x00,0x0f,0xff,0x7f,0xc7 = sthh %r0, 524287
 0xe3,0x00,0x10,0x00,0x00,0xc7 = sthh %r0, 0(%r1)
 0xe3,0x00,0xf0,0x00,0x00,0xc7 = sthh %r0, 0(%r15)
-0xe3,0x01,0xff,0xff,0x7f,0xc7 = sthh %r0, 524287(%r1,%r15)
-0xe3,0x0f,0x1f,0xff,0x7f,0xc7 = sthh %r0, 524287(%r15,%r1)
+0xe3,0x01,0xff,0xff,0x7f,0xc7 = sthh %r0, 524287(%r1, %r15)
+0xe3,0x0f,0x1f,0xff,0x7f,0xc7 = sthh %r0, 524287(%r15, %r1)
 0xe3,0xf0,0x00,0x00,0x00,0xc7 = sthh %r15, 0
 0xe3,0x00,0x00,0x00,0x80,0xcb = stfh %r0, -524288
 0xe3,0x00,0x0f,0xff,0xff,0xcb = stfh %r0, -1
@@ -530,8 +530,8 @@
 0xe3,0x00,0x0f,0xff,0x7f,0xcb = stfh %r0, 524287
 0xe3,0x00,0x10,0x00,0x00,0xcb = stfh %r0, 0(%r1)
 0xe3,0x00,0xf0,0x00,0x00,0xcb = stfh %r0, 0(%r15)
-0xe3,0x01,0xff,0xff,0x7f,0xcb = stfh %r0, 524287(%r1,%r15)
-0xe3,0x0f,0x1f,0xff,0x7f,0xcb = stfh %r0, 524287(%r15,%r1)
+0xe3,0x01,0xff,0xff,0x7f,0xcb = stfh %r0, 524287(%r1, %r15)
+0xe3,0x0f,0x1f,0xff,0x7f,0xcb = stfh %r0, 524287(%r15, %r1)
 0xe3,0xf0,0x00,0x00,0x00,0xcb = stfh %r15, 0
 0xeb,0x00,0x00,0x00,0x00,0xf3 = stoc %r0, 0, 0
 0xeb,0x0f,0x00,0x00,0x00,0xf3 = stoc %r0, 0, 15
@@ -540,7 +540,7 @@
 0xeb,0x00,0x10,0x00,0x00,0xf3 = stoc %r0, 0(%r1), 0
 0xeb,0x00,0xf0,0x00,0x00,0xf3 = stoc %r0, 0(%r15), 0
 0xeb,0xf0,0x00,0x00,0x00,0xf3 = stoc %r15, 0, 0
-0xeb,0x13,0x2f,0xff,0x00,0xf3 = stoc %r1, 4095(%r2), 3
+// 0xeb,0x13,0x2f,0xff,0x00,0xf3 = stoc %r1, 4095(%r2), 3
 0xeb,0x11,0x30,0x02,0x00,0xf3 = stoco %r1, 2(%r3)
 0xeb,0x12,0x30,0x02,0x00,0xf3 = stoch %r1, 2(%r3)
 0xeb,0x13,0x30,0x02,0x00,0xf3 = stocnle %r1, 2(%r3)
@@ -562,7 +562,7 @@
 0xeb,0x00,0x10,0x00,0x00,0xe3 = stocg %r0, 0(%r1), 0
 0xeb,0x00,0xf0,0x00,0x00,0xe3 = stocg %r0, 0(%r15), 0
 0xeb,0xf0,0x00,0x00,0x00,0xe3 = stocg %r15, 0, 0
-0xeb,0x13,0x2f,0xff,0x00,0xe3 = stocg %r1, 4095(%r2), 3
+// 0xeb,0x13,0x2f,0xff,0x00,0xe3 = stocg %r1, 4095(%r2), 3
 0xeb,0x11,0x30,0x02,0x00,0xe3 = stocgo %r1, 2(%r3)
 0xeb,0x12,0x30,0x02,0x00,0xe3 = stocgh %r1, 2(%r3)
 0xeb,0x13,0x30,0x02,0x00,0xe3 = stocgnle %r1, 2(%r3)
